#include "4uhv.h"
#include "ui_4uhv.h"
#include "channel.h"
#include <tango.h>
#include <QMessageBox>
#include <QGridLayout>
#include <TPushButton>
#include <QGroupBox>
#include <QtDebug>

FourUHV::FourUHV(QWidget *parent) :
    QWidget(parent),
    ui(new Ui::FourUHV)
{
    ui->setupUi(this);
    if(qApp->arguments().size() > 1) {
        QString device = qApp->arguments().at(1);
        QStringList parts;
        std::vector<std::string> list;
        Tango::Database *db = new Tango::Database();
        Tango::DbData db_data;
        db_data.push_back(Tango::DbDatum("power_supply"));
        try{
            db->get_property("vacuum", db_data);
            db_data[0] >> list;
            for(size_t i = 0; i < list.size(); i++)
            {
                parts = QString::fromStdString(list.at(i)).split(":");
                if(parts.size() >= 3 && device == parts.first()) {
                    for(int ch = 1; ch < parts.size(); ch++)
                        if(parts[ch].compare("none", Qt::CaseInsensitive) != 0)
                            m_chSensorMap[ch] = parts[ch];
               }
            }
        }
        catch(Tango::DevFailed& e)
        {
            perr("4uhv: error getting power_supply property from \"vacuum\" object");
            QMessageBox::critical(this, "Error getting property from database",
                                  "4uhv: error getting power_supply property from \"vacuum\" object");
        }
    }
    int r = 0, c = 0;
    QGridLayout *glo = new QGridLayout(ui->contentsWidget);
    foreach(int ch, m_chSensorMap.keys()) {
        Channel *channel = new Channel(ui->contentsWidget);
        channel->findChild<QLabel*>("lChannel")->setText(QString("Channel %1 - %2")
                                                         .arg(ch).arg(m_chSensorMap[ch].section('/', -1, -1)));
        foreach(QWidget *w, channel->findChildren<QWidget *>()) {
            if(w->metaObject()->indexOfProperty("source") > -1)
                w->setProperty("source",  QString(w->property("point").toString()).arg(ch));
            if(w->metaObject()->indexOfProperty("targets") > -1)
                w->setProperty("targets", QString(w->property("point").toString()).arg(ch));
        }
        //////////////////////////////////////////////////////////////
        //
        // hide Threshold settings for now
        channel->findChild<QGroupBox *>("gbHighTh")->setHidden(true);
        channel->findChild<QGroupBox *>("gbLowTh")->setHidden(true);
        //
        ///////////////////////////////////////////////////////////////
        glo->addWidget(channel, r, c % 2, 1, 1);
        if(c == 1) {
            c = 0; r++;
        }
        else
            c++;


        foreach(QGroupBox *gb, channel->findChild<QTabWidget *>()->widget(1)->findChildren<QGroupBox *>())
            connect(gb->findChild<TPushButton *>(), SIGNAL(clicked()), this, SLOT(applyThresholdClicked()));
    }

}

FourUHV::~FourUHV()
{
    delete ui;
}

void FourUHV::applyThresholdClicked()
{
    QString onam = sender()->objectName();
    if(sender()->objectName().startsWith("tpbApplyThHigh"))
        findChild<QGroupBox *>("");
}

